/*
 *  
 *  $Id: herramientadesencajar.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <export/iherramientadesencajar.h>
#include <api/api.h>

#include <map>


namespace GNC {

	class EXTAPI HerramientaDesencajar : public GNC::GCS::IHerramientaDesencajar {

	protected:

	public:
		HerramientaDesencajar();
		~HerramientaDesencajar();
		//menu del reset
		virtual bool AppendInMenu(wxWindow* pParent, wxMenu* pMenuParent);

		//region "Realización de la interfaz IHerramienta"

		// Setup de paneles
		virtual void CrearPaneles( wxPanel* pParent );

		//endregion

		//cuando hacen click en ella...
		bool EstaHabilitada();
		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);
		virtual void Desencajar(GNC::GCS::IVista* pVista);
		virtual bool IsDesencajada();

		virtual void ConectarContratoFalso(bool activar);
		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
		virtual void ConectarContratos(bool activar);


	protected:

	};
}
